@@ -13,6 +13,13 @@ def signed_length(first_start: Point, first_end: Point,
     Positive sign of result means that angle between vectors is acute,
     negative -- obtuse,
     zero -- right.
+
+    >>> signed_length((0, 0), (1, 0), (0, 0), (1, 0))
+    1
+    >>> signed_length((0, 0), (1, 0), (0, 0), (0, 1))
+    0
+    >>> signed_length((0, 0), (1, 0), (1, 0), (0, 0))
+    -1
     """
     return parallelogram.signed_area(first_start, first_end,
                                      to_perpendicular_point(second_start),
